@@ -22,11 +22,14 @@ import (
 const (
 	envNamespace = "CLOUDFLARE_"
 
-	EnvEmail        = envNamespace + "EMAIL"
-	EnvAPIKey       = envNamespace + "API_KEY"
+	EnvEmail  = envNamespace + "EMAIL"
+	EnvAPIKey = envNamespace + "API_KEY"
+
 	EnvDNSAPIToken  = envNamespace + "DNS_API_TOKEN"
 	EnvZoneAPIToken = envNamespace + "ZONE_API_TOKEN"
 
+	EnvBaseURL = envNamespace + "BASE_URL"
+
 	EnvTTL                = envNamespace + "TTL"
 	EnvPropagationTimeout = envNamespace + "PROPAGATION_TIMEOUT"
 	EnvPollingInterval    = envNamespace + "POLLING_INTERVAL"
@@ -53,6 +56,8 @@ type Config struct {
 	AuthToken string
 	ZoneToken string
 
+	BaseURL string
+
 	TTL                int
 	PropagationTimeout time.Duration
 	PollingInterval    time.Duration
@@ -114,6 +119,7 @@ func NewDNSProvider() (*DNSProvider, error) {
 	config.AuthKey = values[EnvAPIKey]
 	config.AuthToken = values[EnvDNSAPIToken]
 	config.ZoneToken = values[EnvZoneAPIToken]
+	config.BaseURL = env.GetOrFile(EnvBaseURL)
 
 	return NewDNSProviderConfig(config)
 }
@@ -205,7 +211,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 
 	err = d.client.DeleteDNSRecord(context.Background(), zoneID, recordID)
 	if err != nil {
-		log.Printf("cloudflare: failed to delete TXT record: %w", err)
+		log.Printf("cloudflare: failed to delete TXT record: %v", err)
 	}
 
 	// Delete record ID from map
