@@ -6,11 +6,14 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
 	"github.com/go-acme/lego/v4/providers/dns/joker/internal/svc"
 )
 
+var _ challenge.ProviderTimeout = (*svcProvider)(nil)
+
 // svcProvider implements the challenge.Provider interface.
 type svcProvider struct {
 	config *Config
